pub struct Builder(/* private fields */);Expand description
An object which can be used to construct a script piece by piece.
Implementations
Sourceimpl Builder
impl Builder
Sourcepub fn push_int(self, data: i64) -> Builder
pub fn push_int(self, data: i64) -> Builder
Adds instructions to push an integer onto the stack. Integers are encoded as little-endian signed-magnitude numbers, but there are dedicated opcodes to push some small integers.
Sourcepub fn push_scriptint(self, data: i64) -> Builder
pub fn push_scriptint(self, data: i64) -> Builder
Adds instructions to push an integer onto the stack, using the explicit encoding regardless of the availability of dedicated opcodes.
Sourcepub fn push_slice(self, data: &[u8]) -> Builder
pub fn push_slice(self, data: &[u8]) -> Builder
Adds instructions to push some arbitrary data onto the stack.
Sourcepub fn push_key(self, key: &PublicKey) -> Builder
pub fn push_key(self, key: &PublicKey) -> Builder
Adds instructions to push a public key onto the stack.
Sourcepub fn push_x_only_key(self, x_only_key: &XOnlyPublicKey) -> Builder
pub fn push_x_only_key(self, x_only_key: &XOnlyPublicKey) -> Builder
Adds instructions to push an XOnly public key onto the stack.
Sourcepub fn push_opcode(self, data: All) -> Builder
pub fn push_opcode(self, data: All) -> Builder
Adds a single opcode to the script.
Sourcepub fn push_verify(self) -> Builder
pub fn push_verify(self) -> Builder
Adds an OP_VERIFY to the script, unless the most-recently-added
opcode has an alternate VERIFY form, in which case that opcode
is replaced e.g., OP_CHECKSIG will become OP_CHECKSIGVERIFY.
Sourcepub fn into_script(self) -> Script
pub fn into_script(self) -> Script
Converts the Builder into an unmodifiable Script.