StreamReader

Struct StreamReader 

pub struct StreamReader<R: Read> {
    pub stream: BufReader<R>,
}
Available on crate feature std only.
Struct used to configure stream reader function

Fields

stream: BufReader<R>

Stream to read from

Implementations

Source

impl<R: Read> StreamReader<R>

pub fn new(stream: R, _buffer_size: Option<usize>) -> StreamReader<R>

👎Deprecated since 0.28.0: wrap your stream into a buffered reader if necessary and use consensus_encode directly

Constructs new stream reader for a given input stream stream

pub fn read_next<D: Decodable>(&mut self) -> Result<D, Error>

👎Deprecated since 0.28.0: wrap your stream into a buffered reader if necessary and use consensus_encode directly

Reads stream and parses next message from its current input